@@ -1,9 +1,7 @@
-# encoding: utf-8
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from pkg_resources import DistributionNotFound, get_distribution, parse_version
 
-from haystack import signals
 from haystack.constants import DEFAULT_ALIAS
 from haystack.utils import loading
 
