@@ -1,14 +1,12 @@
-# encoding: utf-8
 import importlib
 import re
 
 from django.conf import settings
 
-from haystack.constants import ID, DJANGO_CT, DJANGO_ID
-from haystack.utils.highlighting import Highlighter
+from haystack.constants import DJANGO_CT, DJANGO_ID, ID
+from haystack.utils.highlighting import Highlighter # noqa=F401
 
-
-IDENTIFIER_REGEX = re.compile("^[\w\d_]+\.[\w\d_]+\.[\w\d-]+$")
+IDENTIFIER_REGEX = re.compile(r"^[\w\d_]+\.[\w\d_]+\.[\w\d-]+$")
 
 
 def default_get_identifier(obj_or_string):
