@@ -1,6 +1,5 @@
-# encoding: utf-8
-from django.conf.urls import include, url
 from django.contrib import admin
+from django.urls import include, path
 
 from haystack.forms import FacetedSearchForm
 from haystack.query import SearchQuerySet
@@ -10,22 +9,22 @@ admin.autodiscover()
 
 
 urlpatterns = [
-    url(r"^admin/", admin.site.urls),
-    url(r"^$", SearchView(load_all=False), name="haystack_search"),
-    url(
-        r"^faceted/$",
+    path("", SearchView(load_all=False), name="haystack_search"),
+    path("admin/", admin.site.urls),
+    path("basic/", basic_search, {"load_all": False}, name="haystack_basic_search"),
+    path(
+        "faceted/",
         FacetedSearchView(
             searchqueryset=SearchQuerySet().facet("author"),
             form_class=FacetedSearchForm,
         ),
         name="haystack_faceted_search",
     ),
-    url(r"^basic/$", basic_search, {"load_all": False}, name="haystack_basic_search"),
 ]
 
 urlpatterns += [
-    url(
-        r"",
+    path(
+        "",
         include(("test_haystack.test_app_without_models.urls", "app-without-models")),
     )
 ]
