@@ -1,7 +1,7 @@
-# -*- coding: utf-8 -*-
 import datetime
 import logging as std_logging
 import operator
+import pickle
 import unittest
 from decimal import Decimal
 
@@ -22,16 +22,6 @@ from haystack.utils.loading import UnifiedIndex
 from ..core.models import AFourthMockModel, AnotherMockModel, ASixthMockModel, MockModel
 from ..mocks import MockSearchResult
 
-test_pickling = True
-
-try:
-    import cPickle as pickle
-except ImportError:
-    try:
-        import pickle
-    except ImportError:
-        test_pickling = False
-
 
 def clear_elasticsearch_index():
     # Wipe it clean.
@@ -126,7 +116,7 @@ class Elasticsearch2BoostMockSearchIndex(indexes.SearchIndex, indexes.Indexable)
         return AFourthMockModel
 
     def prepare(self, obj):
-        data = super(Elasticsearch2BoostMockSearchIndex, self).prepare(obj)
+        data = super().prepare(obj)
 
         if obj.pk == 4:
             data["boost"] = 5.0
@@ -164,7 +154,7 @@ class Elasticsearch2RoundTripSearchIndex(indexes.SearchIndex, indexes.Indexable)
         return MockModel
 
     def prepare(self, obj):
-        prepped = super(Elasticsearch2RoundTripSearchIndex, self).prepare(obj)
+        prepped = super().prepare(obj)
         prepped.update(
             {
                 "text": "This is some example text.",
@@ -241,7 +231,7 @@ class TestSettings(TestCase):
 
 class Elasticsearch2SearchBackendTestCase(TestCase):
     def setUp(self):
-        super(Elasticsearch2SearchBackendTestCase, self).setUp()
+        super().setUp()
 
         # Wipe it clean.
         self.raw_es = elasticsearch.Elasticsearch(
@@ -274,7 +264,7 @@ class Elasticsearch2SearchBackendTestCase(TestCase):
 
     def tearDown(self):
         connections["elasticsearch"]._index = self.old_ui
-        super(Elasticsearch2SearchBackendTestCase, self).tearDown()
+        super().tearDown()
         self.sb.silently_fail = True
 
     def raw_search(self, query):
@@ -580,6 +570,7 @@ class Elasticsearch2SearchBackendTestCase(TestCase):
 
     def test_spatial_search_parameters(self):
         from django.contrib.gis.geos import Point
+
         p1 = Point(1.23, 4.56)
         kwargs = self.sb.build_search_kwargs(
             "*:*",
@@ -766,7 +757,7 @@ class LiveElasticsearch2SearchQueryTestCase(TestCase):
     fixtures = ["base_data.json"]
 
     def setUp(self):
-        super(LiveElasticsearch2SearchQueryTestCase, self).setUp()
+        super().setUp()
 
         # Wipe it clean.
         clear_elasticsearch_index()
@@ -785,7 +776,7 @@ class LiveElasticsearch2SearchQueryTestCase(TestCase):
 
     def tearDown(self):
         connections["elasticsearch"]._index = self.old_ui
-        super(LiveElasticsearch2SearchQueryTestCase, self).tearDown()
+        super().tearDown()
 
     def test_log_query(self):
         reset_search_queries()
@@ -830,7 +821,7 @@ class LiveElasticsearch2SearchQuerySetTestCase(TestCase):
     fixtures = ["bulk_data.json"]
 
     def setUp(self):
-        super(LiveElasticsearch2SearchQuerySetTestCase, self).setUp()
+        super().setUp()
 
         # Stow.
         self.old_ui = connections["elasticsearch"].get_unified_index()
@@ -857,7 +848,7 @@ class LiveElasticsearch2SearchQuerySetTestCase(TestCase):
     def tearDown(self):
         # Restore.
         connections["elasticsearch"]._index = self.old_ui
-        super(LiveElasticsearch2SearchQuerySetTestCase, self).tearDown()
+        super().tearDown()
 
     def test_load_all(self):
         sqs = self.sqs.order_by("pub_date").load_all()
@@ -1273,7 +1264,7 @@ class LiveElasticsearch2SpellingTestCase(TestCase):
     fixtures = ["bulk_data.json"]
 
     def setUp(self):
-        super(LiveElasticsearch2SpellingTestCase, self).setUp()
+        super().setUp()
 
         # Stow.
         self.old_ui = connections["elasticsearch"].get_unified_index()
@@ -1296,7 +1287,7 @@ class LiveElasticsearch2SpellingTestCase(TestCase):
     def tearDown(self):
         # Restore.
         connections["elasticsearch"]._index = self.old_ui
-        super(LiveElasticsearch2SpellingTestCase, self).tearDown()
+        super().tearDown()
 
     def test_spelling(self):
         self.assertEqual(
@@ -1316,7 +1307,7 @@ class LiveElasticsearch2MoreLikeThisTestCase(TestCase):
     fixtures = ["bulk_data.json"]
 
     def setUp(self):
-        super(LiveElasticsearch2MoreLikeThisTestCase, self).setUp()
+        super().setUp()
 
         # Wipe it clean.
         clear_elasticsearch_index()
@@ -1336,7 +1327,7 @@ class LiveElasticsearch2MoreLikeThisTestCase(TestCase):
     def tearDown(self):
         # Restore.
         connections["elasticsearch"]._index = self.old_ui
-        super(LiveElasticsearch2MoreLikeThisTestCase, self).tearDown()
+        super().tearDown()
 
     def test_more_like_this(self):
         mlt = self.sqs.more_like_this(MockModel.objects.get(pk=1))
@@ -1394,7 +1385,7 @@ class LiveElasticsearch2AutocompleteTestCase(TestCase):
     fixtures = ["bulk_data.json"]
 
     def setUp(self):
-        super(LiveElasticsearch2AutocompleteTestCase, self).setUp()
+        super().setUp()
 
         # Stow.
         self.old_ui = connections["elasticsearch"].get_unified_index()
@@ -1417,7 +1408,7 @@ class LiveElasticsearch2AutocompleteTestCase(TestCase):
     def tearDown(self):
         # Restore.
         connections["elasticsearch"]._index = self.old_ui
-        super(LiveElasticsearch2AutocompleteTestCase, self).tearDown()
+        super().tearDown()
 
     def test_build_schema(self):
         self.sb = connections["elasticsearch"].get_backend()
@@ -1510,7 +1501,7 @@ class LiveElasticsearch2AutocompleteTestCase(TestCase):
 
 class LiveElasticsearch2RoundTripTestCase(TestCase):
     def setUp(self):
-        super(LiveElasticsearch2RoundTripTestCase, self).setUp()
+        super().setUp()
 
         # Wipe it clean.
         clear_elasticsearch_index()
@@ -1533,7 +1524,7 @@ class LiveElasticsearch2RoundTripTestCase(TestCase):
     def tearDown(self):
         # Restore.
         connections["elasticsearch"]._index = self.old_ui
-        super(LiveElasticsearch2RoundTripTestCase, self).tearDown()
+        super().tearDown()
 
     def test_round_trip(self):
         results = self.sqs.filter(id="core.mockmodel.1")
@@ -1556,12 +1547,11 @@ class LiveElasticsearch2RoundTripTestCase(TestCase):
         self.assertEqual(result.sites, [3, 5, 1])
 
 
-@unittest.skipUnless(test_pickling, "Skipping pickling tests")
 class LiveElasticsearch2PickleTestCase(TestCase):
     fixtures = ["bulk_data.json"]
 
     def setUp(self):
-        super(LiveElasticsearch2PickleTestCase, self).setUp()
+        super().setUp()
 
         # Wipe it clean.
         clear_elasticsearch_index()
@@ -1582,7 +1572,7 @@ class LiveElasticsearch2PickleTestCase(TestCase):
     def tearDown(self):
         # Restore.
         connections["elasticsearch"]._index = self.old_ui
-        super(LiveElasticsearch2PickleTestCase, self).tearDown()
+        super().tearDown()
 
     def test_pickling(self):
         results = self.sqs.all()
@@ -1599,7 +1589,7 @@ class LiveElasticsearch2PickleTestCase(TestCase):
 
 class Elasticsearch2BoostBackendTestCase(TestCase):
     def setUp(self):
-        super(Elasticsearch2BoostBackendTestCase, self).setUp()
+        super().setUp()
 
         # Wipe it clean.
         self.raw_es = elasticsearch.Elasticsearch(
@@ -1633,7 +1623,7 @@ class Elasticsearch2BoostBackendTestCase(TestCase):
 
     def tearDown(self):
         connections["elasticsearch"]._index = self.old_ui
-        super(Elasticsearch2BoostBackendTestCase, self).tearDown()
+        super().tearDown()
 
     def raw_search(self, query):
         return self.raw_es.search(
@@ -1710,7 +1700,7 @@ class RecreateIndexTestCase(TestCase):
 
 class Elasticsearch2FacetingTestCase(TestCase):
     def setUp(self):
-        super(Elasticsearch2FacetingTestCase, self).setUp()
+        super().setUp()
 
         # Wipe it clean.
         clear_elasticsearch_index()
@@ -1745,7 +1735,7 @@ class Elasticsearch2FacetingTestCase(TestCase):
 
     def tearDown(self):
         connections["elasticsearch"]._index = self.old_ui
-        super(Elasticsearch2FacetingTestCase, self).tearDown()
+        super().tearDown()
 
     def test_facet(self):
         self.sb.update(self.smmi, self.sample_objs)
