@@ -1,4 +1,3 @@
-# encoding: utf-8
 from django.test import TestCase
 
 from haystack import connections, inputs
@@ -6,7 +5,7 @@ from haystack import connections, inputs
 
 class SolrInputTestCase(TestCase):
     def setUp(self):
-        super(SolrInputTestCase, self).setUp()
+        super().setUp()
         self.query_obj = connections["solr"].get_query()
 
     def test_raw_init(self):
