@@ -1,7 +1,7 @@
-# -*- coding: utf-8 -*-
 import datetime
 import logging as std_logging
 import os
+import pickle
 import unittest
 from decimal import Decimal
 from unittest.mock import patch
@@ -22,16 +22,6 @@ from haystack.utils.loading import UnifiedIndex
 from ..core.models import AFourthMockModel, AnotherMockModel, ASixthMockModel, MockModel
 from ..mocks import MockSearchResult
 
-test_pickling = True
-
-try:
-    import cPickle as pickle
-except ImportError:
-    try:
-        import pickle
-    except ImportError:
-        test_pickling = False
-
 
 def clear_solr_index():
     # Wipe it clean.
@@ -134,7 +124,7 @@ class SolrRoundTripSearchIndex(indexes.SearchIndex, indexes.Indexable):
         return MockModel
 
     def prepare(self, obj):
-        prepped = super(SolrRoundTripSearchIndex, self).prepare(obj)
+        prepped = super().prepare(obj)
         prepped.update(
             {
                 "text": "This is some example text.",
@@ -201,7 +191,7 @@ class SolrQuotingMockSearchIndex(indexes.SearchIndex, indexes.Indexable):
 
 class SolrSearchBackendTestCase(TestCase):
     def setUp(self):
-        super(SolrSearchBackendTestCase, self).setUp()
+        super().setUp()
 
         # Wipe it clean.
         self.raw_solr = pysolr.Solr(settings.HAYSTACK_CONNECTIONS["solr"]["URL"])
@@ -230,7 +220,7 @@ class SolrSearchBackendTestCase(TestCase):
 
     def tearDown(self):
         connections["solr"]._index = self.old_ui
-        super(SolrSearchBackendTestCase, self).tearDown()
+        super().tearDown()
 
     def test_non_silent(self):
         bad_sb = connections["solr"].backend(
@@ -871,7 +861,7 @@ class LiveSolrSearchQueryTestCase(TestCase):
     fixtures = ["base_data.json"]
 
     def setUp(self):
-        super(LiveSolrSearchQueryTestCase, self).setUp()
+        super().setUp()
 
         # Wipe it clean.
         clear_solr_index()
@@ -890,7 +880,7 @@ class LiveSolrSearchQueryTestCase(TestCase):
 
     def tearDown(self):
         connections["solr"]._index = self.old_ui
-        super(LiveSolrSearchQueryTestCase, self).tearDown()
+        super().tearDown()
 
     def test_get_spelling(self):
         self.sq.add_filter(SQ(content="Indexy"))
@@ -944,16 +934,16 @@ class LiveSolrSearchQuerySetTestCase(TestCase):
 
     @classmethod
     def setUpClass(cls):
-        super(LiveSolrSearchQuerySetTestCase, cls).setUpClass()
+        super().setUpClass()
         cls._index_updated = False
 
     @classmethod
     def tearDownClass(cls):
         del cls._index_updated
-        super(LiveSolrSearchQuerySetTestCase, cls).tearDownClass()
+        super().tearDownClass()
 
     def setUp(self):
-        super(LiveSolrSearchQuerySetTestCase, self).setUp()
+        super().setUp()
 
         # Stow.
         self.old_ui = connections["solr"].get_unified_index()
@@ -979,7 +969,7 @@ class LiveSolrSearchQuerySetTestCase(TestCase):
     def tearDown(self):
         # Restore.
         connections["solr"]._index = self.old_ui
-        super(LiveSolrSearchQuerySetTestCase, self).tearDown()
+        super().tearDown()
 
     def test_load_all(self):
         sqs = self.sqs.load_all()
@@ -1367,7 +1357,7 @@ class LiveSolrMoreLikeThisTestCase(TestCase):
     fixtures = ["base_data.json", "bulk_data.json"]
 
     def setUp(self):
-        super(LiveSolrMoreLikeThisTestCase, self).setUp()
+        super().setUp()
 
         # Wipe it clean.
         clear_solr_index()
@@ -1387,7 +1377,7 @@ class LiveSolrMoreLikeThisTestCase(TestCase):
     def tearDown(self):
         # Restore.
         connections["solr"]._index = self.old_ui
-        super(LiveSolrMoreLikeThisTestCase, self).tearDown()
+        super().tearDown()
 
     def test_more_like_this(self):
         all_mlt = self.sqs.more_like_this(MockModel.objects.get(pk=1))
@@ -1454,7 +1444,7 @@ class LiveSolrAutocompleteTestCase(TestCase):
     fixtures = ["base_data.json", "bulk_data.json"]
 
     def setUp(self):
-        super(LiveSolrAutocompleteTestCase, self).setUp()
+        super().setUp()
 
         # Wipe it clean.
         clear_solr_index()
@@ -1473,7 +1463,7 @@ class LiveSolrAutocompleteTestCase(TestCase):
     def tearDown(self):
         # Restore.
         connections["solr"]._index = self.old_ui
-        super(LiveSolrAutocompleteTestCase, self).tearDown()
+        super().tearDown()
 
     def test_autocomplete(self):
         autocomplete = self.sqs.autocomplete(text_auto="mod")
@@ -1514,7 +1504,7 @@ class LiveSolrAutocompleteTestCase(TestCase):
 
 class LiveSolrRoundTripTestCase(TestCase):
     def setUp(self):
-        super(LiveSolrRoundTripTestCase, self).setUp()
+        super().setUp()
 
         # Wipe it clean.
         clear_solr_index()
@@ -1537,7 +1527,7 @@ class LiveSolrRoundTripTestCase(TestCase):
     def tearDown(self):
         # Restore.
         connections["solr"]._index = self.old_ui
-        super(LiveSolrRoundTripTestCase, self).tearDown()
+        super().tearDown()
 
     def test_round_trip(self):
         results = self.sqs.filter(id="core.mockmodel.1")
@@ -1560,12 +1550,11 @@ class LiveSolrRoundTripTestCase(TestCase):
         self.assertEqual(result.sites, [3, 5, 1])
 
 
-@unittest.skipUnless(test_pickling, "Skipping pickling tests")
 class LiveSolrPickleTestCase(TestCase):
     fixtures = ["base_data.json", "bulk_data.json"]
 
     def setUp(self):
-        super(LiveSolrPickleTestCase, self).setUp()
+        super().setUp()
 
         # Wipe it clean.
         clear_solr_index()
@@ -1586,7 +1575,7 @@ class LiveSolrPickleTestCase(TestCase):
     def tearDown(self):
         # Restore.
         connections["solr"]._index = self.old_ui
-        super(LiveSolrPickleTestCase, self).tearDown()
+        super().tearDown()
 
     def test_pickling(self):
         results = self.sqs.all()
@@ -1603,7 +1592,7 @@ class LiveSolrPickleTestCase(TestCase):
 
 class SolrBoostBackendTestCase(TestCase):
     def setUp(self):
-        super(SolrBoostBackendTestCase, self).setUp()
+        super().setUp()
 
         # Wipe it clean.
         self.raw_solr = pysolr.Solr(settings.HAYSTACK_CONNECTIONS["solr"]["URL"])
@@ -1635,7 +1624,7 @@ class SolrBoostBackendTestCase(TestCase):
 
     def tearDown(self):
         connections["solr"]._index = self.old_ui
-        super(SolrBoostBackendTestCase, self).tearDown()
+        super().tearDown()
 
     def test_boost(self):
         self.sb.update(self.smmi, self.sample_objs)
@@ -1662,7 +1651,7 @@ class SolrBoostBackendTestCase(TestCase):
 )
 class LiveSolrContentExtractionTestCase(TestCase):
     def setUp(self):
-        super(LiveSolrContentExtractionTestCase, self).setUp()
+        super().setUp()
 
         self.sb = connections["solr"].get_backend()
 
