@@ -1,10 +1,11 @@
-# encoding: utf-8
 import datetime
 from decimal import Decimal
 from unittest.mock import Mock
 
 from django.template import TemplateDoesNotExist
 from django.test import TestCase
+
+from haystack.fields import *
 from test_haystack.core.models import (
     ManyToManyLeftSideModel,
     ManyToManyRightSideModel,
@@ -14,8 +15,6 @@ from test_haystack.core.models import (
     OneToManyRightSideModel,
 )
 
-from haystack.fields import *
-
 
 class SearchFieldTestCase(TestCase):
     def test_get_iterable_objects_with_none(self):
@@ -68,7 +67,7 @@ class SearchFieldTestCase(TestCase):
         )
 
     def test_resolve_attributes_lookup_with_field_that_points_to_none_but_is_allowed_to_be_null(
-        self
+        self,
     ):
         related = Mock(spec=["none_field"], none_field=None)
         obj = Mock(spec=["related"], related=[related])
@@ -80,7 +79,7 @@ class SearchFieldTestCase(TestCase):
         )
 
     def test_resolve_attributes_lookup_with_field_that_points_to_none_but_has_default(
-        self
+        self,
     ):
         related = Mock(spec=["none_field"], none_field=None)
         obj = Mock(spec=["related"], related=[related])
