@@ -1,10 +1,13 @@
-# encoding: utf-8
 import datetime
 import queue
 import time
 from threading import Thread
 
 from django.test import TestCase
+
+from haystack import connections, indexes
+from haystack.exceptions import SearchFieldError
+from haystack.utils.loading import UnifiedIndex
 from test_haystack.core.models import (
     AFifthMockModel,
     AnotherMockModel,
@@ -14,10 +17,6 @@ from test_haystack.core.models import (
     MockModel,
 )
 
-from haystack import connections, indexes
-from haystack.exceptions import SearchFieldError
-from haystack.utils.loading import UnifiedIndex
-
 
 class BadSearchIndex1(indexes.SearchIndex, indexes.Indexable):
     author = indexes.CharField(model_attr="author")
@@ -63,7 +62,7 @@ class GoodCustomMockSearchIndex(indexes.SearchIndex, indexes.Indexable):
     hello = indexes.CharField(model_attr="hello")
 
     def prepare(self, obj):
-        super(GoodCustomMockSearchIndex, self).prepare(obj)
+        super().prepare(obj)
         self.prepared_data["whee"] = "Custom preparation."
         return self.prepared_data
 
@@ -154,7 +153,7 @@ class SearchIndexTestCase(TestCase):
     fixtures = ["base_data"]
 
     def setUp(self):
-        super(SearchIndexTestCase, self).setUp()
+        super().setUp()
         self.sb = connections["default"].get_backend()
         self.mi = GoodMockSearchIndex()
         self.cmi = GoodCustomMockSearchIndex()
@@ -199,7 +198,7 @@ class SearchIndexTestCase(TestCase):
 
     def tearDown(self):
         connections["default"]._index = self.old_unified_index
-        super(SearchIndexTestCase, self).tearDown()
+        super().tearDown()
 
     def test_no_contentfield_present(self):
         self.assertRaises(SearchFieldError, BadSearchIndex1)
@@ -245,15 +244,15 @@ class SearchIndexTestCase(TestCase):
         self.assertTrue(isinstance(self.cmi.fields["extra"], indexes.CharField))
 
     def test_index_queryset(self):
-        self.assertEqual(len(self.cmi.index_queryset()), 3)
+        self.assertEqual(self.cmi.index_queryset().count(), 3)
 
     def test_read_queryset(self):
-        self.assertEqual(len(self.cmi.read_queryset()), 2)
+        self.assertEqual(self.cmi.read_queryset().count(), 2)
 
     def test_build_queryset(self):
         # The custom SearchIndex.build_queryset returns the same records as
         # the read_queryset
-        self.assertEqual(len(self.cmi.build_queryset()), 2)
+        self.assertEqual(self.cmi.build_queryset().count(), 2)
 
         # Store a reference to the original method
         old_guf = self.mi.__class__.get_updated_field
@@ -710,7 +709,7 @@ class PolymorphicModelSearchIndex(indexes.SearchIndex, indexes.Indexable):
         return AnotherMockModel
 
     def prepare(self, obj):
-        self.prepared_data = super(PolymorphicModelSearchIndex, self).prepare(obj)
+        self.prepared_data = super().prepare(obj)
         if isinstance(obj, AThirdMockModel):
             self.prepared_data["average_delay"] = obj.average_delay
         return self.prepared_data
@@ -760,7 +759,7 @@ class ModelWithManyToManyFieldModelSearchIndex(indexes.ModelSearchIndex):
 
 class ModelSearchIndexTestCase(TestCase):
     def setUp(self):
-        super(ModelSearchIndexTestCase, self).setUp()
+        super().setUp()
         self.sb = connections["default"].get_backend()
         self.bmsi = BasicModelSearchIndex()
         self.fmsi = FieldsModelSearchIndex()
