@@ -1,14 +1,13 @@
-# encoding: utf-8
 import logging as std_logging
 import pickle
 
 from django.test import TestCase
-from test_haystack.core.models import MockModel
 
 from haystack import connections
 from haystack.models import SearchResult
 from haystack.utils import log as logging
 from haystack.utils.loading import UnifiedIndex
+from test_haystack.core.models import MockModel
 
 from .mocks import MockSearchResult
 from .test_indexes import ReadQuerySetTestSearchIndex
@@ -25,7 +24,7 @@ class SearchResultTestCase(TestCase):
     fixtures = ["base_data"]
 
     def setUp(self):
-        super(SearchResultTestCase, self).setUp()
+        super().setUp()
         cap = CaptureHandler()
         logging.getLogger("haystack").addHandler(cap)
 
