@@ -1,4 +1,3 @@
-# encoding: utf-8
 """Tests for Whoosh spelling suggestions"""
 from django.conf import settings
 from django.http import HttpRequest
@@ -19,13 +18,13 @@ class SpellingSuggestionTestCase(LiveWhooshRoundTripTestCase):
         )
         settings.HAYSTACK_CONNECTIONS["whoosh"]["INCLUDE_SPELLING"] = True
 
-        super(SpellingSuggestionTestCase, self).setUp()
+        super().setUp()
 
     def tearDown(self):
         settings.HAYSTACK_CONNECTIONS["whoosh"][
             "INCLUDE_SPELLING"
         ] = self.old_spelling_setting
-        super(SpellingSuggestionTestCase, self).tearDown()
+        super().tearDown()
 
     def test_form_suggestion(self):
         form = SearchForm({"q": "exampl"}, searchqueryset=SearchQuerySet("whoosh"))
